==> kde4libs_3.93.0.orig.tar.gz: kde4libs-3.93.0.orig/kdeui/actions/krecentfilesaction_p.h <==
/* This file is part of the KDE libraries
    Copyright (C) 1999 Reginald Stadlbauer <reggie@kde.org>
              (C) 1999 Simon Hausmann <hausmann@kde.org>
              (C) 2000 Nicolas Hadacek <haadcek@kde.org>
              (C) 2000 Kurt Granroth <granroth@kde.org>
              (C) 2000 Michael Koch <koch@kde.org>
              (C) 2001 Holger Freyther <freyther@kde.org>
              (C) 2002 Ellis Whitehead <ellis@kde.org>
              (C) 2002 Joseph Wenninger <jowenn@kde.org>
              (C) 2003 Andras Mantia <amantia@kde.org>
              (C) 2005-2006 Hamish Rodda <rodda@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef KRECENTFILESACTION_P_H
#define KRECENTFILESACTION_P_H

#include "kselectaction_p.h"

class KRecentFilesActionPrivate : public KSelectActionPrivate
{
public:
  KRecentFilesActionPrivate()
  {
    m_maxItems = 10;
    m_noEntriesAction=0;
  }

  int m_maxItems;
  QMap<QAction*, QString> m_shortNames;
  QMap<QAction*, KUrl> m_urls;
  QPointer<QAction> m_noEntriesAction;
};

/* vim: et sw=2 ts=2
 */

#endif // KRECENTFILESACTION_P_H

==> kde4libs_4.2.4.orig.tar.gz: kde4libs-4.2.4.orig/kdeui/actions/krecentfilesaction_p.h <==
/* This file is part of the KDE libraries
    Copyright (C) 1999 Reginald Stadlbauer <reggie@kde.org>
              (C) 1999 Simon Hausmann <hausmann@kde.org>
              (C) 2000 Nicolas Hadacek <haadcek@kde.org>
              (C) 2000 Kurt Granroth <granroth@kde.org>
              (C) 2000 Michael Koch <koch@kde.org>
              (C) 2001 Holger Freyther <freyther@kde.org>
              (C) 2002 Ellis Whitehead <ellis@kde.org>
              (C) 2002 Joseph Wenninger <jowenn@kde.org>
              (C) 2003 Andras Mantia <amantia@kde.org>
              (C) 2005-2006 Hamish Rodda <rodda@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef KRECENTFILESACTION_P_H
#define KRECENTFILESACTION_P_H

#include "kselectaction_p.h"

class KRecentFilesActionPrivate : public KSelectActionPrivate
{
    Q_DECLARE_PUBLIC(KRecentFilesAction)

public:
  KRecentFilesActionPrivate()
  {
    m_maxItems = 10;
    m_noEntriesAction=0;
  }

  virtual ~KRecentFilesActionPrivate()
  {
  }

  void init();

  void _k_urlSelected(QAction*);

  int m_maxItems;
  QMap<QAction*, QString> m_shortNames;
  QMap<QAction*, KUrl> m_urls;
  QPointer<QAction> m_noEntriesAction;
};

/* vim: et sw=2 ts=2
 */

#endif // KRECENTFILESACTION_P_H
